==> models_weebi-1.0.22.tar.gz: lib/src/extensions/next_id.dart <==
import 'package:mobx/mobx.dart';
import 'package:models_weebi/base.dart';
import 'package:models_weebi/src/models/article_calibre.dart';

extension NextLineArticleId on ObservableList<ArticleCalibre> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = this
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}

extension NextArticleId<A extends ArticleAbstract> on Iterable<A> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = toList()
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}

extension NextHerderId<H extends HerderAbstract> on Iterable<H> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = toList()
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}

extension NextShopId<S extends ShopAbstract> on Iterable<S> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = toList()
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}

extension NextTicketId<T extends TicketAbstract> on ObservableSet<T> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = toList()
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}

==> models_weebi-1.1.2.tar.gz: lib/src/extensions/next_id.dart <==
import 'package:mobx/mobx.dart';
import 'package:models_weebi/abstracts.dart';
import 'package:models_weebi/src/models/article/calibre.dart';

extension NextLineArticleId on ObservableList<Calibre> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = this
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}

extension NextArticleId<A extends ArticleRawAbstract> on Iterable<A> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = toList()
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}

extension NextContactId<C extends ContactAbstract> on Iterable<C> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = toList()
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}

extension NextBoutiqueId<S extends BoutiqueAbstract> on Iterable<S> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = toList()
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}

extension NextTicketId<T extends TicketRawAbstract> on ObservableSet<T> {
  int get nextId {
    if (isEmpty) {
      return 1;
    } else {
      final that = toList()
        ..sort((a, b) => a.id.compareTo(b.id))
        ..toList();
      if (that.last.id < 0) {
        return 1;
      } else {
        return that.last.id + 1;
      }
    }
  }
}
